#
# spec file for package EternalTerminal
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _firewalld_dir %{_prefix}/lib/firewalld
%if 0%{?sle_version} >= 150300
%define forced_gcc_version -10
BuildRequires:  gcc10-c++
%else
BuildRequires:  gcc-c++
%endif
Name:           EternalTerminal
Version:        6.2.8
Release:        2.1
Summary:        Remote shell that survives IP roaming and disconnect
License:        Apache-2.0
URL:            https://mistertea.github.io/EternalTerminal/
Source0:        https://github.com/MisterTea/EternalTerminal/archive/et-v%{version}.tar.gz
Source1:        et.xml
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  curl-devel
BuildRequires:  firewall-macros
BuildRequires:  firewalld
BuildRequires:  gflags-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libsodium-devel
BuildRequires:  ncurses-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  protobuf-devel
BuildRequires:  utempter-devel
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}

%description
Eternal Terminal (ET) is a remote shell that automatically reconnects without
interrupting the session.

%prep
%autosetup -n EternalTerminal-et-v%{version} -p1

%build

%if 0%{?forced_gcc_version:1}
export CC=gcc%{?forced_gcc_version}
export CXX=g++%{?forced_gcc_version}
%endif
export CXXFLAGS="%{optflags} -std=c++17"
# see https://github.com/MisterTea/EternalTerminal/issues/403
%cmake -DDISABLE_VCPKG:BOOL=ON -DProtobuf_LITE_LIBRARY=%{_libdir}/libprotobuf-lite.so
%make_build

%install
%cmake_install

mkdir -p \
  %{buildroot}%{_unitdir} \
  %{buildroot}%{_sysconfdir} \
  %{buildroot}%{_firewalld_dir}/services
install -m 0644 -p systemctl/et.service %{buildroot}%{_unitdir}/et.service
install -m 0644 -p etc/et.cfg %{buildroot}%{_sysconfdir}/et.cfg
install -m 0644 %{SOURCE1} %{buildroot}%{_firewalld_dir}/services/et.xml
mv %{buildroot}%{_bindir}/et %{buildroot}%{_bindir}/et-client

# https://github.com/MisterTea/EternalTerminal/issues/601
rm %{buildroot}%{_includedir}/httplib.h
rm %{buildroot}%{_libdir}/cmake/httplib/*.cmake

%pre
%service_add_pre et.service

%post
%service_add_post et.service
%firewalld_reload

%preun
%service_del_preun et.service

%postun
%service_del_postun et.service
%firewalld_reload

%files
%license LICENSE
%doc README.md
%{_bindir}/et-client
%{_bindir}/etserver
%{_bindir}/etterminal
%{_bindir}/htm
%{_bindir}/htmd
%dir %{_firewalld_dir}
%dir %{_firewalld_dir}/services
%{_firewalld_dir}/services/et.xml
%config(noreplace) %{_sysconfdir}/et.cfg
%{_unitdir}/et.service

%changelog
* Tue Feb 13 2024 Otto Hollmann <otto.hollmann@suse.com>
- Remove the hardcoded libopenssl-1_1-devel and replace it with
  libopenssl-devel (bsc#1219879).
* Fri Sep  1 2023 Michael Vetter <mvetter@suse.com>
- Update to 6.2.8:
  * Upgrade catch2 to fix another gcc13 error.
* Fri Sep  1 2023 Michael Vetter <mvetter@suse.com>
- Update to 6.2.7
  * Fixes errors in release build & CI
- Drop ET-gcc13.patch
* Wed Apr 12 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add ET-gcc13.patch: Fix build using GCC 13.
* Mon Mar 13 2023 Michael Vetter <mvetter@suse.com>
- Move binary 'et' to 'et-client'
  There is a naming conflict with 'erdtree' and it makes more sense
  to have that with the shorter name.
  Additionally I think EternalTerminal isn't used that much.
  And they last CVEs were handled not so well which is why we even
  think about dropping it in the future
* Fri Jan 20 2023 Michael Vetter <mvetter@suse.com>
- Update to 6.2.4:
  * CVE-2022-48257, CVE-2022-48258 remedied
  * fix readme regarding port forwarding #522
  * Fix test failures that started appearing in CI #526
  * Add documentation for the EternalTerminal protocol #523
  * ssh-et: apply upstream updates #527
  * docs: write gpg key to trusted.gpg.d for APT #530
  * Support for ipv6 addresses (with or without port specified) #536
  * ipv6 abbreviated address support #539
  * Fix launchd plist config to remove daemonization. #540
  * Explicitly set verbosity from cxxopts value. #542
  * Remove daemon flag in systemd config #549
  * Format all source with clang-format. #552
  * Fix tunnel parsing exception handling. #550
  * Fix SIGTERM behavior that causes systemd control of etserver to timeout. #554
  * Parse telemetry ini config as boolean and make telemetry opt-in. #553
  * Logfile open mode and permission plus location configurability. #556
- bsc#1207123 (CVE-2022-48257) Fix predictable logfile names in /tmp
- bsc#1207124 (CVE-2022-48258) Fix etserver and etclient have world-readable logfiles
- Note: Upstream released 6.2.2 with fixes then 6.2.4 and later removed 6.2.2
  and redid 6.2.4
* Mon Nov  7 2022 Max Lin <mlin@suse.com>
- Hard buildrequires gcc10-c++ in Leap 15.5
* Thu Aug 18 2022 Michael Vetter <mvetter@suse.com>
- Require gcc-c++ instead of gcc12-c++ in most cases
  This will be gcc12-c++ on TW by default
  In Leap 15.3/15.4 hard-require gcc10-c++ since the build fails with
  older versions
* Fri May  6 2022 Michael Vetter <mvetter@suse.com>
- Update to 6.2.1:
  * Fix build issues
- Remove upstreamed patches:
  * EternalTerminal-6.2.0-return.patch
  * EternalTerminal-6.2.0-optional.patch
* Thu May  5 2022 Michael Vetter <mvetter@suse.com>
- Update to 6.2.0:
  * Several security and stability improvements.
  * CVE-2022-24949 [bsc#1202435]
  * CVE-2022-24950 [bsc#1202434]
  * CVE-2022-24951 [bsc#1202433]
  * CVE-2022-24952 [bsc#1202432]
- Add EternalTerminal-6.2.0-return.patch
  See https://github.com/MisterTea/EternalTerminal/pull/518
- Add EternalTerminal-6.2.0-optional.patch
* Thu Jan 13 2022 Michael Vetter <mvetter@suse.com>
- Update to 6.1.11:
  * Compile fixes for later versions of gcc
- Remove et-limits.patch: upstreamed
* Thu Nov  4 2021 Michael Vetter <mvetter@suse.com>
- Update to 6.1.9:
  * Security & Compatibility fixes
* Mon May 31 2021 Michael Vetter <mvetter@suse.com>
- Update to 6.1.8:
  * ssh config fixes
- Add et-limits.patch:
  Fix build by patching in-tree sentry.
  See https://github.com/MisterTea/EternalTerminal/issues/412
  and https://github.com/getsentry/sentry-native/issues/501
* Wed Apr  7 2021 Michael Vetter <mvetter@suse.com>
- Update to 6.1.7:
  * Fix race condition in connection test
  * Reduce debug object size
  * Move deployment scripts to deployment branch
  * Do not install files from PlatformFolders project
* Wed Apr  7 2021 Michael Vetter <mvetter@suse.com>
- Update to 6.1.6:
  * Fix crash on exit.
  * Fix ARM build.
* Wed Apr  7 2021 Michael Vetter <mvetter@suse.com>
- Update to 6.1.5:
  * Fixes for various OSes
  * Update sentry version
* Sun Mar 14 2021 Michael Vetter <mvetter@suse.com>
- Update to 6.1.4:
  * Add stack trace on unhandled exception
* Mon Mar  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 6.1.3:
  * Fixes for various OSes and build systems
  * Allow older cmake versions on non-windows platforms
  * Fix for older cmake versions
* Fri Mar  5 2021 Michael Vetter <mvetter@suse.com>
- Update to 6.1.0:
  * Build using vcpkg
  * Monitor crashes
  * Fix some race conditions
  * Add --ssh-option argument for passing arguments to ssh
  * Android support
* Thu Nov 19 2020 Michael Vetter <mvetter@suse.com>
- Update to 6.0.13:
  * Fix warning by systemctl (#346)
  * Import UST
  * Several documentation fixes
* Mon Aug  3 2020 Michael Vetter <mvetter@suse.com>
- Update to 6.0.11:
  * Fix version number
* Mon Aug  3 2020 Michael Vetter <mvetter@suse.com>
- Update to 6.0.10:
  * Fix --help and --version flags
* Fri Jul 31 2020 Michael Vetter <mvetter@suse.com>
- Update to 6.0.9:
  * TSAN fixes
  * Pass errno correctly from ::read
* Thu Jul 30 2020 Michael Vetter <mvetter@suse.com>
- Update to 6.0.8:
  * TSAN/ASAN fixes
  * Parse named socket port forwards (#293)
  * Fix input for forward tunnels (#319)
  * Revert back to write/read instead of send/recv on unix (#323, #322)
  * Handle SIGINT manually (#333, #324)
- Build with DISABLE_CRASH_LOG=OFF since SIGINT is now not handled
  by easylogging++ anymore, thus ctrl+c won't lead to crash
* Wed Jun 24 2020 Michael Vetter <mvetter@suse.com>
- Build with DISABLE_CRASH_LOG=ON to prevent segfault upon abort
  See https://github.com/MisterTea/EternalTerminal/issues/324
* Wed Mar  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 6.0.7:
  * Add Match Host support to ssh config
* Mon Feb 17 2020 Michael Vetter <mvetter@suse.com>
- Update to 6.0.6:
  * Generate passkeys on server (#280)
* Fri Dec 27 2019 Michael Vetter <mvetter@suse.com>
- Update to 6.0.5:
  * Fix SSH config parsing bug when Hostname is specified (#235)
  * Expand tilde before parsing include file (#244)
  * Add a build option to disable easylogging's default
    crash handler (#246)
  * Several bug fixes
* Wed Nov 27 2019 Michael Vetter <mvetter@suse.com>
- Initial package 6.0.4 for openSUSE
